.. functions:

==========================
Functions
==========================

This section lists all the functions available within the
:ref:`domain specific language <index-dsl>`. Each function can
be stand-alone or in combination with other others.

In the following list we assume the following shortcuts:

.. math::

	\Delta x_t &= \Delta_1 x_t = x_t - x_{t-1}\\
	\Delta^2 x_t &= \Delta_1^2 x_t = \Delta_1 x_t - \Delta_1 x_{t-1}



.. dyntslist::
